# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litepci/okr/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/litepci/okr/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Litepci\\Okr\\": "packages/litepci/okr/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litepci\Okr\Providers\OkrServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Okr'  => Litepci\Okr\Facades\Okr::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litepci\\OkrTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litepci\Okr\Providers\OkrServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litepci\Okr\Providers\OkrServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litepci\Okr\Providers\OkrServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/okr/{modulename}

**User**

    http://path-to-route-folder/user/okr/{modulename}

**Public**

    http://path-to-route-folder/okrs


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/okr/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/okr/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/okr/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/okr/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/okr/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/okr/{modulename}/{slug}
    METHOD: GET