<?php

namespace Litepci\Okr\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepci\Okr\Interfaces\ActivityRepositoryInterface;

class ActivityPublicController extends BaseController
{
    // use ActivityWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepci\Activity\Interfaces\ActivityRepositoryInterface $activity
     *
     * @return type
     */
    public function __construct(ActivityRepositoryInterface $activity)
    {
        $this->repository = $activity;
        parent::__construct();
    }

    /**
     * Show activity's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $activities = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('okr::activity.names'))
            ->view('okr::public.activity.index')
            ->data(compact('activities'))
            ->output();
    }


    /**
     * Show activity.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $activity = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($activity->name . trans('okr::activity.name'))
            ->view('okr::public.activity.show')
            ->data(compact('activity'))
            ->output();
    }

}
