<?php

namespace Litepci\Okr\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepci\Okr\Models\Goal;

class GoalPolicy
{

    /**
     * Determine if the given user can view the goal.
     *
     * @param UserPolicy $user
     * @param Goal $goal
     *
     * @return bool
     */
    public function view(UserPolicy $user, Goal $goal)
    {
        if ($user->canDo('okr.goal.view') && $user->isAdmin()) {
            return true;
        }

        return $goal->user_id == user_id() && $goal->user_type == user_type();
    }

    /**
     * Determine if the given user can create a goal.
     *
     * @param UserPolicy $user
     * @param Goal $goal
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('okr.goal.create');
    }

    /**
     * Determine if the given user can update the given goal.
     *
     * @param UserPolicy $user
     * @param Goal $goal
     *
     * @return bool
     */
    public function update(UserPolicy $user, Goal $goal)
    {
        if ($user->canDo('okr.goal.edit') && $user->isAdmin()) {
            return true;
        }

        return $goal->user_id == user_id() && $goal->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given goal.
     *
     * @param UserPolicy $user
     * @param Goal $goal
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Goal $goal)
    {
        return $goal->user_id == user_id() && $goal->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given goal.
     *
     * @param UserPolicy $user
     * @param Goal $goal
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Goal $goal)
    {
        if ($user->canDo('okr.goal.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given goal.
     *
     * @param UserPolicy $user
     * @param Goal $goal
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Goal $goal)
    {
        if ($user->canDo('okr.goal.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
