<?php

namespace Litepci\Okr\Providers;

use Illuminate\Support\ServiceProvider;

class OkrServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'okr');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'okr');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerOkr();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerOkr()
    {
        $this->app->bind('okr', function($app) {
            return new Okr($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Okr', 'Lavalite\Okr\Facades\Okr');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litepci.okr', function ($app) {
            return $this->app->make('Litepci\Okr\Okr');
        });

        // Bind Goal to repository
        $this->app->bind(
            'Litepci\Okr\Interfaces\GoalRepositoryInterface',
            \Litepci\Okr\Repositories\Eloquent\GoalRepository::class
        );        // Bind Activity to repository
        $this->app->bind(
            'Litepci\Okr\Interfaces\ActivityRepositoryInterface',
            \Litepci\Okr\Repositories\Eloquent\ActivityRepository::class
        );

        $this->app->register(\Litepci\Okr\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litepci\Okr\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and okr's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litepci.okr'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeOkr::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litepci.okr'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litepci/okr.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/okr')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/okr')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
