<?php

namespace Litepci\Okr\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litepci\Okr\Models\Okr;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litepci\Okr\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/okr/goal/*')) {
            Route::bind('goal', function ($goal) {
                $goalrepo = $this->app->make('Litepci\Okr\Interfaces\GoalRepositoryInterface');
                return $goalrepo->findorNew($goal);
            });
        }
        if (Request::is('*/okr/activity/*')) {
            Route::bind('activity', function ($activity) {
                $activityrepo = $this->app->make('Litepci\Okr\Interfaces\ActivityRepositoryInterface');
                return $activityrepo->findorNew($activity);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
